﻿using Microsoft.AspNetCore.Mvc;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;

namespace RecipeManager.DataAccess
{

    [ModelMetadataType(typeof(IngredientModelMetadata))]
    public partial class Ingredient : IValidatableObject
    {
        private readonly RecipeManagerContext _context;

        public Ingredient(RecipeManagerContext context)
        {
            _context = context;
        }

        public IEnumerable<ValidationResult> Validate(ValidationContext validationContext)
        {
            var results = new List<ValidationResult>();

            var duplicates = _context.Ingredient
                .Where(i =>
                    i.IngredientName.Replace(" ", "").ToLower() == IngredientName.Replace(" ", "").ToLower());
            if (IngredientId > 0) // This is an update
            {
                duplicates = duplicates.Where(i => i.IngredientId != IngredientId);
            }

            if (duplicates.Any())
            {
                results.Add(new ValidationResult(
                    $"{IngredientName} already exists in the database",
                    new List<string>{
                         nameof(IngredientName)
                    }));
            }

            return results;
        }
    }
}
