using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using RecipeManager.DataAccess;
using RecipeManager.FrontEnd.Classes;
using RecipeManager.FrontEnd.Config;
using System.Threading.Tasks;

namespace RecipeManager.FrontEnd.Pages.IngredientPages
{
    public class DeleteModel : RecipeManagerPageModel
    {
        #region Constructor

        public DeleteModel(RecipeManagerContext context)
            : base (context)
        { }

        #endregion

        #region Properties

        public Ingredient Ingredient { get; set; }

        #endregion

        #region Get

        public async Task<IActionResult> OnGetAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            Ingredient = await _context.Ingredient
                .Include(i => i.RecipeIngredient)
                .FirstOrDefaultAsync(i => i.IngredientId == id);

            if (Ingredient == null)
            {
                return NotFound();
            }

            return Page();
        }

        #endregion

        #region Post

        public async Task<IActionResult> OnPostAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            Ingredient = await _context.Ingredient.FindAsync(id);

            if (Ingredient != null)
            {
                _context.Ingredient.Remove(Ingredient);
                await _context.SaveChangesAsync();
            }

            return RedirectToPage(ConfigValues.Pages.IngredientIndex);
        }

        #endregion
    }
}
