﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using RecipeManager.DataAccess;
using RecipeManager.FrontEnd.Classes;
using RecipeManager.FrontEnd.Config;
using System.Threading.Tasks;

namespace RecipeManager.FrontEnd.Pages.IngredientPages
{
    public class EditModel : RecipeManagerPageModel
    {
        #region Constructor

        public EditModel(RecipeManagerContext context)
            : base (context)
        {
        }

        #endregion

        #region Properties

        public Ingredient Ingredient { get; set; }

        #endregion

        #region Get
        
        public async Task<IActionResult> OnGetAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            Ingredient = await _context.Ingredient.FirstOrDefaultAsync(m => m.IngredientId == id);

            if (Ingredient == null)
            {
                return NotFound();
            }
            return Page();
        }

        #endregion

        #region Post

        public async Task<IActionResult> OnPostAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            if (!ModelState.IsValid)
            {
                return Page();
            }

            Ingredient = await _context.Ingredient.FirstOrDefaultAsync(m => m.IngredientId == id);

            if (Ingredient == null)
            {
                return NotFound();
            }

            if (await TryUpdateModelAsync(
                Ingredient,
                nameof(Ingredient),
                i => i.IngredientId, i => i.IngredientName))
            {
                await _context.SaveChangesAsync();
                return RedirectToPage(ConfigValues.Pages.IngredientIndex);
            }

            return Page();
        }

        #endregion
    }
}
