﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Rendering;
using RecipeManager.DataAccess;
using RecipeManager.FrontEnd.Classes;
using RecipeManager.FrontEnd.Config;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace RecipeManager.FrontEnd.Pages.RecipePages
{
    public class CreateModel : RecipeManagerPageModel
    {
        #region Constructor

        public CreateModel(RecipeManagerContext context)
            : base (context)
        {
        }

        #endregion

        #region Properties

        public Recipe Recipe { get; set; }

        public MultiSelectList SlIngredients { get; set; }

        public List<int> SelectedIngredientIds { get => new List<int>(); set { } }

        #endregion

        #region Get

        public IActionResult OnGet()
        {
            GetIngredients();
            return Page();
        }

        #endregion

        #region Post

        public async Task<IActionResult> OnPostAsync()
        {
            // Can't any other way of getting this from the form
            var ingredientIds = Request.Form[nameof(SelectedIngredientIds)];

            if (!ModelState.IsValid)
            {
                GetIngredients();
                return Page();
            }

            var newRecipe = new Recipe
            {
                RecipeIngredient = new List<RecipeIngredient>()
            };

            if (await TryUpdateModelAsync(
                newRecipe,
                nameof(Recipe),
                r => r.RecipeName, r => r.Description))
            {
                foreach (var ingredientId in ingredientIds)
                {
                    newRecipe.RecipeIngredient.Add(new RecipeIngredient
                    {
                        RecipeId = newRecipe.RecipeId,
                        IngredientId = Convert.ToInt32(ingredientId)
                    });
                }

                _context.Recipe.Add(newRecipe);
                await _context.SaveChangesAsync();
                return RedirectToPage(ConfigValues.Pages.RecipeIndex);
            }

            GetIngredients();
            return Page();
        }

        #endregion

        #region Private Methods

        private void GetIngredients()
            => SlIngredients = new MultiSelectList(
                _context.Ingredient.OrderBy(i => i.IngredientName),
                nameof(Ingredient.IngredientId),
                nameof(Ingredient.IngredientName));

        #endregion
    }
}
