using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using RecipeManager.DataAccess;
using RecipeManager.FrontEnd.Classes;
using RecipeManager.FrontEnd.Config;
using System.Threading.Tasks;

namespace RecipeManager.FrontEnd.Pages.RecipePages
{
    public class DeleteModel : RecipeManagerPageModel
    {
        #region Constructor

        public DeleteModel(RecipeManagerContext context)
            : base (context)
        { }

        #endregion

        #region Properties

        public Recipe Recipe { get; set; }

        #endregion

        #region Get

        public async Task<IActionResult> OnGetAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            Recipe = await _context.Recipe
                .Include(r => r.RecipeIngredient)
                .ThenInclude(ri => ri.Ingredient)
                .FirstOrDefaultAsync(r => r.RecipeId == id);

            if (Recipe == null)
            {
                return NotFound();
            }
            return Page();
        }

        #endregion

        #region Post

        public async Task<IActionResult> OnPostAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            Recipe = await _context.Recipe
                .Include(r => r.RecipeIngredient)
                .Include(r => r.RecipeStep)
                .FirstOrDefaultAsync(r => r.RecipeId == id);

            if (Recipe != null)
            {
                foreach (var recipeIngredient in Recipe.RecipeIngredient)
                {
                    _context.RecipeIngredient.Remove(recipeIngredient);
                }
                foreach (var recipeStep in Recipe.RecipeStep)
                {
                    _context.Remove(recipeStep);
                }
                _context.Recipe.Remove(Recipe);
                await _context.SaveChangesAsync();
            }

            return RedirectToPage(ConfigValues.Pages.RecipeIndex);
        }

        #endregion
    }
}
