﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Rendering;
using Microsoft.EntityFrameworkCore;
using RecipeManager.DataAccess;
using RecipeManager.FrontEnd.Classes;
using RecipeManager.FrontEnd.Config;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace RecipeManager.FrontEnd.Pages.RecipePages
{
    public class EditModel : RecipeManagerPageModel
    {
        #region Constructor

        public EditModel(RecipeManagerContext context)
            : base (context)
        {
        }

        #endregion

        #region Properties

        public Recipe Recipe { get; set; }

        public MultiSelectList SlIngredients { get; set; }

        public List<int> SelectedIngredientIds { get; set; }

        #endregion

        #region Get

        public async Task<IActionResult> OnGetAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            var idConverted = Convert.ToInt32(id);

            await GetRecipe(idConverted);

            if (Recipe == null)
            {
                return NotFound();
            }

            SelectedIngredientIds = new List<int>();

            foreach(var recipeIngredient in Recipe.RecipeIngredient)
            {
                SelectedIngredientIds.Add(recipeIngredient.IngredientId);
            }

            SlIngredients = new SelectList(
                await _context.Ingredient.OrderBy(i => i.IngredientName).ToListAsync(),
                nameof(Ingredient.IngredientId),
                nameof(Ingredient.IngredientName));

            return Page();
        }

        #endregion

        #region Post

        public async Task<IActionResult> OnPostAsync(int? id)
        {
            var ingredientIds = Request.Form[nameof(SelectedIngredientIds)];

            if(id == null)
            {
                return NotFound();
            }

            var idConverted = Convert.ToInt32(id);

            if (!ModelState.IsValid)
            {
                await GetRecipe(idConverted);
                await GetIngredients();
                return Page();
            }

            await GetRecipe(idConverted);

            if (Recipe == null)
            {
                return NotFound();
            }

            if (await TryUpdateModelAsync(
                Recipe,
                nameof(Recipe),
                r => r.RecipeId, r => r.RecipeName, r => r.Description))
            {
                // Remove all the previous RecipeIngredients
                foreach (var recipeIngredient in Recipe.RecipeIngredient)
                {
                    _context.RecipeIngredient.Remove(recipeIngredient);
                }

                foreach (var ingredientId in ingredientIds)
                {
                    // And create new ones
                    Recipe.RecipeIngredient.Add(new RecipeIngredient
                    {
                        RecipeId = Recipe.RecipeId,
                        IngredientId = Convert.ToInt32(ingredientId)
                    });
                }

                await _context.SaveChangesAsync();
                return RedirectToPage(ConfigValues.Pages.RecipeIndex);
            }

            await GetIngredients();
            return Page();
        }

        #endregion

        #region Private Methods

        private async Task GetRecipe(int id)
            => Recipe = await _context.Recipe
                .Include(r => r.RecipeIngredient)
                .FirstOrDefaultAsync(m => m.RecipeId == id);

        private async Task GetIngredients()
            => SlIngredients = new SelectList(
                await _context.Ingredient.OrderBy(i => i.IngredientName).ToListAsync(),
                nameof(Ingredient.IngredientId),
                nameof(Ingredient.IngredientName));

        #endregion
    }
}
