﻿using Microsoft.AspNetCore.Mvc;
using RecipeManager.DataAccess;
using RecipeManager.FrontEnd.Classes;
using RecipeManager.FrontEnd.Config;
using System;
using System.Threading.Tasks;

namespace RecipeManager.FrontEnd.Pages.RecipeStepPages
{
    public class CreateModel : RecipeManagerPageModel
    {
        #region Constructor

        public CreateModel(RecipeManagerContext context)
            : base (context)
        {
        }

        #endregion

        #region Properties

        public RecipeStep RecipeStep { get; set; }

        public Recipe Recipe { get; set; }

        #endregion

        #region Get

        public IActionResult OnGet(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            Recipe = _context.Recipe.Find(id);

            return Page();
        }

        #endregion

        #region Post

        public async Task<IActionResult> OnPostAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            if (!ModelState.IsValid)
            {
                return Page();
            }

            var recipeId = Convert.ToInt32(id);

            var newRecipeStep = new RecipeStep
            {
                RecipeId = recipeId
            };

            if (await TryUpdateModelAsync(
                newRecipeStep,
                nameof(RecipeStep),
                r => r.RecipeStepText))
            {
                _context.RecipeStep.Add(newRecipeStep);
                await _context.SaveChangesAsync();
                return RedirectToPage(ConfigValues.StringValues.RecipeDetailsPage, new { Id = recipeId });
            }

            return Page();
        }

        #endregion
    }
}
