﻿using Microsoft.AspNetCore.Mvc;
using RecipeManager.DataAccess;
using RecipeManager.FrontEnd.Classes;
using RecipeManager.FrontEnd.Config;
using System.Threading.Tasks;

namespace RecipeManager.FrontEnd.Pages.RecipeStepPages
{
    public class EditModel : RecipeManagerPageModel
    {
        #region Constructor

        public EditModel(RecipeManagerContext context)
            : base (context)
        {
        }

        #endregion

        #region Properties

        public RecipeStep RecipeStep { get; set; }

        #endregion

        #region Get

        public async Task<IActionResult> OnGetAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }

            RecipeStep = await _context.RecipeStep
                .FindAsync(id);

            if (RecipeStep == null)
            {
                return NotFound();
            }
            
            return Page();
        }

        #endregion

        #region Post

        public async Task<IActionResult> OnPostAsync(int? id)
        {
            if (id == null)
            {
                return NotFound();
            }
            
            if (!ModelState.IsValid)
            {
                return Page();
            }

            RecipeStep = await _context.RecipeStep.FindAsync(id);

            if (RecipeStep == null)
            {
                return NotFound();
            }

            if (await TryUpdateModelAsync(
                RecipeStep,
                nameof(RecipeStep),
                r => r.RecipeStepText))
            {
                await _context.SaveChangesAsync();
                return RedirectToPage(ConfigValues.StringValues.RecipeDetailsPage, new { Id = RecipeStep.RecipeId });
            }

            return RedirectToPage("./Index");
        }

        #endregion
    }
}
